@@ -2,7 +2,7 @@ import click
 
 from apigee import console
 from apigee.auth import common_auth_options, gen_auth
-from apigee.cls import OptionEatAll
+# from apigee.cls import OptionEatAll
 # from apigee.prefix import common_prefix_options
 from apigee.silent import common_silent_options
 from apigee.userroles.userroles import Userroles
@@ -80,8 +80,8 @@ def _create_a_user_role_in_an_organization(
     username, password, mfa_secret, token, zonename, org, profile, names, **kwargs
 ):
     return (
-        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, names)
-        .create_a_user_role_in_an_organization()
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, None)
+        .create_a_user_role_in_an_organization(names)
         .text
     )
 
@@ -90,9 +90,10 @@ def _create_a_user_role_in_an_organization(
 @common_auth_options
 @common_verbose_options
 @common_silent_options
-@click.option(
-    '-n', '--names', metavar='LIST', cls=OptionEatAll, help='list of role names', required=True
-)
+# @click.option(
+#     '-n', '--names', metavar='LIST', cls=OptionEatAll, help='list of role names', required=True
+# )
+@click.option('-n', '--names', multiple=True, help='role names', required=True)
 def create(*args, **kwargs):
     console.echo(_create_a_user_role_in_an_organization(*args, **kwargs))
 
